package net.pricefx.common.apibuilder.calculationflowaction;

import net.pricefx.common.apibuilder.Invocations;

/**
 * This action starts selected Price API job. It's a programmatic version
 * of the same action available in UI. As such it allows user to schedule the
 * action in calculation flow formula.
 */
public class PriceAPIAction<ATTACHEDTO extends Help> extends Action {

	private String jobName;
	private Boolean execute;
	private ATTACHEDTO backLink;
	
	public PriceAPIAction(ATTACHEDTO backLink, Invocations<MethodInvocationRecord> invocations, String jobName) {
		super(invocations);
		this.backLink = backLink;
		this.jobName = jobName;
		this.execute = false;
	}

	/**
	 * Whether the action is valid and should be executed or not.
	 * 
	 * @param execute
	 *            <ul>
	 *            <li>true - calculation of the Price API job is started as
	 *            background process</li>
	 *            <li>false - calculation of the Price API job is NOT started at
	 *            all</li>
	 *            </ul>
	 */
	public PriceAPIAction<ATTACHEDTO> setExecute(Boolean execute) {
		invocations.add(MethodInvocationRecord.of(getObjectName() + ".setExecute", execute));
		this.execute = Boolean.TRUE.equals(execute) ? true : false;
		return this;
	}
	
	public ATTACHEDTO back() {
		invocations.add(MethodInvocationRecord.of(getObjectName() + ".back"));
		return backLink;
	}

	@Override
	public String getObjectName() {
		return backLink.getObjectName() + ".PriceAPIAction";
	}

	public String getJobName() { return jobName; }
	public Boolean getExecute() {	return execute; }
	@Override public String toString() { return "PriceAPIAction [jobName=" + jobName	+ ", execute=" + execute + ", backLink=" + backLink
				+  ", hashCode()=" + hashCode() + "]";
	}
	
}