package net.pricefx.formulaengine;

import net.pricefx.common.api.pa.LoadMode;
import net.pricefx.formulaengine.DatamartContext.DataLoader;
import net.pricefx.formulaengine.DatamartContext.Table;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

public interface DistFormulaContext {

	String getTarget();

	LoadMode getLoadMode();

	List<String> getTargetFields();

	List<Object> getAllocationFields();

	LocalDateTime getIncLoadDate();

	Table getResultTable();

	/**
	 * In a distributed calculation step, this method retrieves the item to be calculated.  This item will have been created by a previous
	 * initialization
	 *
	 * @return The LookupTable entry as a map, e.g.  [Key1: "Pricing", Key2: "Segment 001", Value: ["EMEA", "Retail"] ]
	 */
	Map<String, Object> getCalcItem();

	/**
	 * Creates a new or updates an existing calculation item (entry in the Model CalcItems PP) for a given <code>(key1,key2)</code> combination.)
	 *
	 * @param key1  <Code>Key1</Code> of the calculation item
	 * @param key2  <Code>Key2</Code> of the calculation item
	 * @param value A JSON-serializable value to be stored in the <code>Value</code> attribute of the calculation item
	 * @return
	 */
	Object addOrUpdateCalcItem(Object key1, Object key2, Object value);

	DataLoader getDataLoader();

}
