package net.pricefx.formulaengine.optimization;

import com.googlecode.genericdao.search.Filter;

import java.util.Collection;

public interface ModelFilterTreesContextReadWrite extends ModelFilterTreesContextReadOnly {
    /**
     * @param name The name of the {@link MutableFilterTree} owned by this model
     * @return A {@link MutableFilterTree} or {@code null} if it doesn't exist
     */
    @Override
    MutableFilterTree tree(String name);

    interface MutableFilterTree extends FilterTree {
        /**
         * Delete this tree
         */
        void drop();
    }

    /**
     * Add a tree that will be owned by this model.
     * <p>
     * If the tree already exists, it is deleted and replaced by this new tree.
     * <p>
     * Here is an example of a tree representation:
     * <pre><code>
     * def myTree = model.addTree(
     *     "Segments",
     *     new NodeSpec(
     *         name: "Segments",
     *         label: "the root",
     *         children: [
     *             new NodeSpec(
     *                name: "S1",
     *                label: "avg=0.189",
     *                filter: Filter.equals("CategoryA", "foo")
     *             ),
     *             new NodeSpec(
     *                name: "S2",
     *                label: "avg=0.345",
     *                filter: Filter.lessOrEqual("CategoryA", "bar")
     *             )
     *         ]
     *     )
     * )
     * </code></pre>
     *
     * @param name The name of the new tree, must be unique per model
     * @param root The representation of the tree to add
     * @return the new {@link MutableFilterTree}
     */
    MutableFilterTree addTree(String name, NodeSpec root);

    /**
     * Represents an in-memory tree.
     *
     * @see #addTree(String, NodeSpec)
     */
    final class NodeSpec {
        public String name;
        public String label;
        public Filter filter;
        public Collection<NodeSpec> children;
    }
}
