package net.pricefx.formulaengine.scripting.inputbuilder;

import net.pricefx.common.api.InputType;
import net.pricefx.common.api.PriceFxInterface;
import net.pricefx.common.api.chart.TieredValueSortType;
import net.pricefx.common.api.chart.TieredValueValidationType;

/**
 * Builder class for input type MultiTierEntry {@link InputType#MULTITIERENTRY}.
 */
public class MultiTierInputBuilder<VT> extends AbstractInputBuilder<MultiTierInputBuilder, VT> {

    public MultiTierInputBuilder(InputBuilderContext builderContext, String paramName) {
        super(builderContext, InputType.MULTITIERENTRY, paramName);
    }

    /**
     * Set tiered value sort type.
     * <p>Example:
     * <blockquote><pre>
     * import net.pricefx.common.api.chart.TieredValueValidationType
     * import net.pricefx.common.api.chart.TieredValueSortType
     *
     * api.inputBuilderFactory()
     *      .createMultiTierEntryInputBuilder("multiEntry")
     *      .setSortType(TieredValueSortType.ASC)
     *      .setValidationType(TieredValueValidationType.NO_VALIDATION)
     *      .buildContextParameter()
     * </pre></blockquote>
     *
     * @param sortType Tiered value sort type
     * @return self
     */
    public MultiTierInputBuilder setSortType(TieredValueSortType sortType) {
        cp.addParameterConfigEntry(PriceFxInterface.PARAM_MT_SORTTYPE, sortType.name());
        return this;
    }

    /**
     * Set tiered value validation type.
     * <p>Example:
     * <blockquote><pre>
     * import net.pricefx.common.api.chart.TieredValueValidationType
     * import net.pricefx.common.api.chart.TieredValueSortType
     *
     * api.inputBuilderFactory()
     *      .createMultiTierEntryInputBuilder("multiEntry")
     *      .setSortType(TieredValueSortType.ASC)
     *      .setValidationType(TieredValueValidationType.NO_VALIDATION)
     *      .buildContextParameter()
     * </pre></blockquote>
     *
     * @param validationType Tiered value validation type
     * @return self
     */
    public MultiTierInputBuilder setValidationType(TieredValueValidationType validationType) {
        cp.addParameterConfigEntry(PriceFxInterface.PARAM_MT_VALIDATIONTYPE, validationType.name());
        return this;
    }
}
