package net.pricefx.formulaengine.scripting.inputbuilder;

import net.pricefx.common.api.InputType;
import net.pricefx.common.api.PriceFxInterface;

/**
 * Builder class for input type ProductGroup, CustomerGroup and SellerGroup.
 * ({@link InputType#PRODUCTGROUP}, {@link InputType#CUSTOMERGROUP} and {@link InputType#SELLERGROUP}).
 */
public class PCGroupInputBuilder extends AbstractProductAndCustomerInputBuilder<PCGroupInputBuilder, String> {

    public PCGroupInputBuilder(InputBuilderContext builderContext, InputType type, String paramName) {
        super(builderContext, type, paramName);
    }

    /**
     * Set 'paSearchable' config.
     * <p>Example:
     * <blockquote><pre>
     * api.inputBuilderFactory()
     *      .createProductGroupEntry()
     *      .setPaSearchable(true)     // turn on paSearchable configuration
     *      .buildContextParameter()
     * </pre></blockquote>
     *
     * @param paSearchable searchable flag
     * @return self
     */
    public PCGroupInputBuilder setPaSearchable(Boolean paSearchable) {
        if (paSearchable != null && paSearchable.booleanValue()) {
            cp.addParameterConfigEntry(PriceFxInterface.FIELD_CONTEXTPARAM_CONFIG_PASEARCHABLE, true);
        }
        return this;
    }

}
