package net.pricefx.formulaengine.scripting.inputbuilder;

import net.pricefx.common.api.InputType;
import net.pricefx.common.api.PriceFxInterface;

/**
 * Builder class for input type Seller {@link InputType#SELLER}
 */

public class SellerInputBuilder extends AbstractProductAndCustomerInputBuilder<SellerInputBuilder, String> {

    private Boolean defaultFromParent;

    public SellerInputBuilder(InputBuilderContext builderContext, String paramName) {
        super(builderContext, InputType.SELLER, paramName);
    }

    /**
     * Set default from the parent flag of the SellerInputBuilder.
     * It determines whether to look up the attribute value from the parent seller (if any)
     * <p>Example:
     * <blockquote><pre>
     * api.inputBuilderFactory()
     *         .createSellerEntry()
     *         .buildContextParameter()
     * </pre></blockquote>
     *
     * @param defaultFromParent true to set the default from the parent
     * @return self
     */
    public SellerInputBuilder setDefaultFromParent(Boolean defaultFromParent) {
        this.defaultFromParent = defaultFromParent;
        return this;
    }

}
